@@ -96,8 +96,8 @@ $icons["mml"]  = "ooo_formula.png";
 $icons["default"] = "default.png";
 
 class UI {
-	function getStyles() {
-		GLOBAL $settings;
+	function getStyles() { /* {{{ */
+		global $settings;
 
 		$themes = array();
 		$path = $settings->_rootDir . "styles/";
@@ -111,9 +111,9 @@ class UI {
 		}
 		closedir($handle);
 		return $themes;
-	}
+	} /* }}} */
 
-	function htmlStartPage($title="", $bodyClass="") {
+	function htmlStartPage($title="", $bodyClass="") { /* {{{ */
 		global $theme, $settings;
 
 		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n".
@@ -127,14 +127,14 @@ class UI {
 		echo "<title>".(strlen($settings->_siteName)>0 ? $settings->_siteName : "LetoDMS").(strlen($title)>0 ? ": " : "").$title."</title>\n";
 		echo "</head>\n";
 		echo "<body".(strlen($bodyClass)>0 ? " class=\"".$bodyClass."\"" : "").">\n";
-	}
+	} /* }}} */
 
-	function htmlEndPage() {
+	function htmlEndPage() { /* {{{ */
 		UI::footNote();
 		echo "</body>\n</html>\n";
-	}
+	} /* }}} */
 
-	function footNote() {
+	function footNote() { /* {{{ */
 		global $settings;
 		
 		if ($settings->_printDisclaimer){
@@ -146,9 +146,9 @@ class UI {
 		}
 	
 		return;
-	}
+	} /* }}} */
 
-	function globalBanner() {
+	function globalBanner() { /* {{{ */
 		global $settings;
 
 		echo "<div class=\"globalBox\" id=\"noNav\">\n";
@@ -160,9 +160,9 @@ class UI {
 		echo "<div style=\"clear: both; height: 0px; font-size:0;\">&nbsp;</div>\n".
 			"</div>\n";
 		return;
-	}
+	} /* }}} */
 
-	function globalNavigation($folder=null) {
+	function globalNavigation($folder=null) { /* {{{ */
 	
 		global $settings, $user;
 
@@ -201,9 +201,9 @@ class UI {
 		echo "<div style=\"clear: both; height: 0px; font-size:0;\">&nbsp;</div>\n".
 			"</div>\n";
 		return;
-	}
+	} /* }}} */
 
-	function pageNavigation($pageTitle, $pageType=null, $extra=null) {
+	function pageNavigation($pageTitle, $pageType=null, $extra=null) { /* {{{ */
 		global $settings, $user;
 
 		echo "<div class=\"headingContainer\">\n";
@@ -239,9 +239,9 @@ class UI {
 		}
 
 		return;
-	}
+	} /* }}} */
 
-	function folderNavigationBar($folder) {
+	function folderNavigationBar($folder) { /* {{{ */
 	
 		global $user, $settings, $theme;
 
@@ -259,7 +259,8 @@ class UI {
 		else if ($accessMode >= M_READWRITE) {
 			echo "<li id=\"first\"><a href=\"../out/out.AddSubFolder.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("add_subfolder")."</a></li>\n";
 			echo "<li><a href=\"../out/out.AddDocument.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("add_document")."</a></li>\n";
-			echo "<li><a href=\"../out/out.AddMultiDocument.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("add_multiple_documents")."</a></li>\n";
+			if($settings->_enableLargeFileUpload)
+				echo "<li><a href=\"../out/out.AddMultiDocument.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("add_multiple_documents")."</a></li>\n";
 			echo "<li><a href=\"../out/out.EditFolder.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("edit_folder_props")."</a></li>\n";
 			echo "<li><a href=\"../out/out.FolderNotify.php?folderid=". $folderID ."&showtree=".showtree()."\">".getMLText("edit_existing_notify")."</a></li>\n";
 			if ($folderID != $settings->_rootFolderID && $folder->getParent())
@@ -272,9 +273,9 @@ class UI {
 		}
 		echo "</ul>\n";
 		return;
-	}
+	} /* }}} */
 
-	function documentNavigationBar()	{
+	function documentNavigationBar()	{ /* {{{ */
 	
 		global $user, $settings, $document;
 
@@ -309,9 +310,9 @@ class UI {
 		}
 		echo "</ul>\n";
 		return;
-	}
+	} /* }}} */
 
-	function accountNavigationBar() {
+	function accountNavigationBar() { /* {{{ */
 	
 		global $settings,$user;
 		
@@ -329,9 +330,9 @@ class UI {
 		}		
 		echo "</ul>\n";
 		return;
-	}
+	} /* }}} */
 
-	function myDocumentsNavigationBar() {
+	function myDocumentsNavigationBar() { /* {{{ */
 
 		echo "<ul class=\"localNav\">\n";
 		echo "<li id=\"first\"><a href=\"../out/out.MyDocuments.php?inProcess=1\">".getMLText("documents_in_process")."</a></li>\n";
@@ -340,9 +341,9 @@ class UI {
 		echo "<li><a href=\"../out/out.ApprovalSummary.php\">".getMLText("approval_summary")."</a></li>\n";
 		echo "</ul>\n";
 		return;
-	}
+	} /* }}} */
 
-	function adminToolsNavigationBar() {
+	function adminToolsNavigationBar() { /* {{{ */
 	
 		global $settings;
 
@@ -355,9 +356,9 @@ class UI {
 		echo "<li><a href=\"../out/out.DefaultKeywords.php\">".getMLText("global_default_keywords")."</a></li>\n";
 		echo "</ul>\n";
 		return;
-	}
+	} /* }}} */
 	
-	function calendarNavigationBar($d){
+	function calendarNavigationBar($d){ /* {{{ */
 
 		global $settings,$user;
 
@@ -371,9 +372,9 @@ class UI {
 		echo "</ul>\n";
 		return;
 	
-	}
+	} /* }}} */
 
-	function pageList($pageNumber, $totalPages, $baseURI, $params) {
+	function pageList($pageNumber, $totalPages, $baseURI, $params) { /* {{{ */
 
 		if (!is_numeric($pageNumber) || !is_numeric($totalPages) || $totalPages<2) {
 			return;
@@ -414,9 +415,9 @@ class UI {
 		echo "</div>";
 
 		return;
-	}
+	} /* }}} */
 
-	function contentContainer($content) {
+	function contentContainer($content) { /* {{{ */
 
 		echo "<div class=\"contentContainer\">\n";
 		echo "<div class=\"content\">\n";
@@ -424,32 +425,35 @@ class UI {
 		echo $content;
 		echo "</div></div></div></div>\n</div>\n</div>\n";
 		return;
-	}
-	function contentContainerStart() {
+	} /* }}} */
+
+	function contentContainerStart() { /* {{{ */
 
 		echo "<div class=\"contentContainer\">\n";
 		echo "<div class=\"content\">\n";
 		echo "<div class=\"content-l\"><div class=\"content-r\"><div class=\"content-br\"><div class=\"content-bl\">\n";
 		return;
-	}
-	function contentContainerEnd() {
+	} /* }}} */
+
+	function contentContainerEnd() { /* {{{ */
 
 		echo "</div></div></div></div>\n</div>\n</div>\n";
 		return;
-	}
+	} /* }}} */
 
-	function contentHeading($heading) {
+	function contentHeading($heading) { /* {{{ */
 
 		echo "<div class=\"contentHeading\">".$heading."</div>\n";
 		return;
-	}
-	function contentSubHeading($heading, $first=false) {
+	} /* }}} */
+
+	function contentSubHeading($heading, $first=false) { /* {{{ */
 
 		echo "<div class=\"contentSubHeading\"".($first ? " id=\"first\"" : "").">".$heading."</div>\n";
 		return;
-	}
+	} /* }}} */
 
-	function getMimeIcon($fileType) {
+	function getMimeIcon($fileType) { /* {{{ */
 		global $icons;
 
 		$ext = strtolower(substr($fileType, 1));
@@ -459,9 +463,9 @@ class UI {
 		else {
 			return $icons["default"];
 		}
-	}
+	} /* }}} */
 
-	function printDateChooser($defDate = -1, $varName) {
+	function printDateChooser($defDate = -1, $varName) { /* {{{ */
 	
 		if ($defDate == -1)
 			$defDate = mktime();
@@ -496,9 +500,9 @@ class UI {
 			print ">" . $i . "</option>\n";
 		}
 		print "</select>";
-	}
+	} /* }}} */
 
-	function printSequenceChooser($objArr, $keepID = -1) {
+	function printSequenceChooser($objArr, $keepID = -1) { /* {{{ */
 		if (count($objArr) > 0) {
 			$max = $objArr[count($objArr)-1]->getSequence() + 1;
 			$min = $objArr[0]->getSequence() - 1;
@@ -522,9 +526,9 @@ class UI {
 			print "  <option value=\"".$index."\">" . getMLText("seq_after", array("prevname" => $objArr[$i]->getName() ) );
 		}
 		print "</select>";
-	}
+	} /* }}} */
 	
-	function printDocumentChooser($formName) {
+	function printDocumentChooser($formName) { /* {{{ */
 		global $settings;
 		?>
 		<script language="JavaScript">
@@ -537,9 +541,9 @@ class UI {
 		print "<input type=\"Hidden\" name=\"docid".$formName."\">";
 		print "<input disabled name=\"docname".$formName."\">";
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("document")."...\" onclick=\"chooseDoc".$formName."();\">";
-	}
+	} /* }}} */
 
-	function printFolderChooser($formName, $accessMode, $exclude = -1, $default = false) {
+	function printFolderChooser($formName, $accessMode, $exclude = -1, $default = false) { /* {{{ */
 		global $settings;
 		?>
 		<script language="JavaScript">
@@ -552,9 +556,9 @@ class UI {
 		print "<input type=\"Hidden\" name=\"targetid".$formName."\" value=\"". (($default) ? $default->getID() : "") ."\">";
 		print "<input disabled name=\"targetname".$formName."\" value=\"". (($default) ? $default->getName() : "") ."\">";
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("folder")."...\" onclick=\"chooseFolder".$formName."();\">";
-	}
+	} /* }}} */
 
-	function printCategoryChooser($formName, $categories=array()) {
+	function printCategoryChooser($formName, $categories=array()) { /* {{{ */
 		global $settings;
 ?>
 		<script language="JavaScript">
@@ -575,9 +579,9 @@ class UI {
 		print "<input type=\"hidden\" name=\"categoryid".$formName."\" value=\"".implode(',', $ids)."\">";
 		print "<input disabled name=\"categoryname".$formName."\" value=\"".implode(' ', $names)."\">";
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("category")."...\" onclick=\"chooseCategory".$formName."();\">";
-	}
+	} /* }}} */
 
-	function getImgPath($img) {
+	function getImgPath($img) { /* {{{ */
 		global $theme;
 
 		if ( is_file("../styles/$theme/images/$img") ) {
@@ -587,11 +591,11 @@ class UI {
 			return "../styles/$theme/img/$img";
 		}
 		return "../out/images/$img";
-	}
+	} /* }}} */
 
-	function printImgPath($img) {
+	function printImgPath($img) { /* {{{ */
 		print UI::getImgPath($img);
-	}
+	} /* }}} */
 
 	function exitError($pagetitle,$error) { /* {{{ */
 	
@@ -792,7 +796,7 @@ mayscript>
 <?php
 	foreach($attributes as $name=>$value) {
 ?>
-        attr = attrSet.createStringAttribute( '<?= $name ?>', <?= $value ?> );
+        attr = attrSet.createStringAttribute( '<?= $name ?>', '<?= $value ?>' );
         attr.setSendToServer(true);
 <?php
 	}
@@ -991,14 +995,16 @@ mayscript>
          var content = "";
          var uploader = document.jumpLoaderApplet.getUploader();
          var files = uploader.getAllFiles();
-        	var file = getSelectedFile();
-				 for (var i = 0; i < uploader.getFileCount() ; i++) { 
-				 		if(uploader.getFile(i).getID() == file.getID())
-							content += listFileAttributes( uploader.getFile(i), 1, i );
-						else
-							content += listFileAttributes( uploader.getFile(i), 0, i );
-         }
-         document.getElementById( "fileList" ).innerHTML = content;
+         var file = getSelectedFile();
+				 if(file) {
+					 for (var i = 0; i < uploader.getFileCount() ; i++) { 
+						 if(uploader.getFile(i).getIndex() == file.getIndex())
+							 content += listFileAttributes( uploader.getFile(i), 1, i );
+						 else
+							 content += listFileAttributes( uploader.getFile(i), 0, i );
+					 }
+					 document.getElementById( "fileList" ).innerHTML = content;
+				 }
     }
      /**
       * update attributes for the selected file
