@@ -19,7 +19,7 @@
 
 class LetoDMS_Version {
 
-	var $_number = "3.1.0-RC1";
+	var $_number = "3.2.1";
 	var $_string = "LetoDMS";
 
 	function LetoDMS_Version() {
