@@ -1,7 +1,6 @@
 <?php
-ini_set('include_path', '.:/etc/letodms-webdav:/usr/share/php');
+#ini_set('include_path', '.:/etc/letodms-webdav:/usr/share/php');
 
-include("config.php");
 include("Log.php");
 include("letodms_webdav.php");
 include("../inc/inc.Settings.php");
@@ -12,7 +11,15 @@ $db->_conn->Execute("set names 'utf8'");
 
 $dms = new LetoDMS_Core_DMS($db, $settings->_contentDir.$settings->_contentOffsetDir);
 
-$log = Log::factory('file', $g_config['logfile']);
+if($settings->_logFileEnable) {
+	if ($settings->_logFileRotation=="h") $logname=date("YmdH", time());
+	else if ($settings->_logFileRotation=="d") $logname=date("Ymd", time());
+	else $logname=date("Ym", time());
+	$logname = $settings->_contentDir."webdav-".$logname.".log";
+	$log = Log::factory('file', $logname);
+} else {
+	$log = null;
+}
 
 $server = new HTTP_WebDAV_Server_LetoDMS();
 $server->ServeRequest($dms, $log);
